@@ -3,7 +3,7 @@
 //
 // Copyright 2000-2009 by Wilson Snyder.  This program is free software;
 // you can redistribute it and/or modify it under the terms of either the GNU
-// General Public License or the Perl Artistic License.
+// Lesser General Public License or the Perl Artistic License.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -110,11 +110,14 @@ public:
     virtual void endcellCb(VFileLine* fl, const string& kwd) = 0;
     virtual void endinterfaceCb(VFileLine* fl, const string& kwd) = 0;
     virtual void endmoduleCb(VFileLine* fl, const string& kwd) = 0;
+    virtual void endpackageCb(VFileLine* fl, const string& kwd) = 0;
     virtual void endtaskfuncCb(VFileLine* fl, const string& kwd) = 0;
     virtual void functionCb(VFileLine* fl, const string& kwd, const string& name, const string& type) = 0;
+    virtual void importCb(VFileLine* fl, const string& name) = 0;
     virtual void instantCb(VFileLine* fl, const string& mod, const string& cell, const string& range) = 0;
     virtual void interfaceCb(VFileLine* fl, const string& kwd, const string& name) = 0;
     virtual void moduleCb(VFileLine* fl, const string& kwd, const string& name, bool celldefine) = 0;
+    virtual void packageCb(VFileLine* fl, const string& kwd, const string& name) = 0;
     virtual void paramPinCb(VFileLine* fl, const string& name, const string& conn, int number) = 0;
     virtual void pinCb(VFileLine* fl, const string& name, const string& conn, int number) = 0;
     virtual void portCb(VFileLine* fl, const string& name) = 0;
